@@ -754,6 +754,8 @@ impl Engine {
                         let scope = &mut Scope::new();
                         let environ = fn_ptr.environ.as_ref().map(<_>::as_ref);
 
+                        defer! { let orig_level = global.level; global.level += 1 }
+
                         self.call_script_fn(
                             global, caches, scope, None, environ, fn_def, args, true, pos,
                         )
@@ -791,12 +793,15 @@ impl Engine {
                 }
 
                 // FnPtr call on object
-                let fn_ptr = call_args[0].take().try_cast_raw::<FnPtr>().map_err(|v| {
-                    self.make_type_mismatch_err::<FnPtr>(
-                        self.map_type_name(v.type_name()),
-                        first_arg_pos,
-                    )
-                })?;
+                let fn_ptr = call_args[0]
+                    .take()
+                    .try_cast_result::<FnPtr>()
+                    .map_err(|v| {
+                        self.make_type_mismatch_err::<FnPtr>(
+                            self.map_type_name(v.type_name()),
+                            first_arg_pos,
+                        )
+                    })?;
 
                 #[cfg(not(feature = "no_function"))]
                 let (
@@ -829,6 +834,8 @@ impl Engine {
                         let this_ptr = Some(target.as_mut());
                         let environ = environ.as_deref();
 
+                        defer! { let orig_level = global.level; global.level += 1 }
+
                         self.call_script_fn(
                             global, caches, scope, this_ptr, environ, &fn_def, args, true, pos,
                         )
@@ -970,6 +977,8 @@ impl Engine {
                         let this_ptr = Some(target.as_mut());
                         let args = &mut call_args.iter_mut().collect::<FnArgsVec<_>>();
 
+                        defer! { let orig_level = global.level; global.level += 1 }
+
                         self.call_script_fn(
                             global, caches, scope, this_ptr, environ, &fn_def, args, true, pos,
                         )
@@ -1033,7 +1042,7 @@ impl Engine {
                 let (first_arg_value, first_arg_pos) =
                     self.get_arg_value(global, caches, scope, this_ptr.as_deref_mut(), arg)?;
 
-                let fn_ptr = first_arg_value.try_cast_raw::<FnPtr>().map_err(|v| {
+                let fn_ptr = first_arg_value.try_cast_result::<FnPtr>().map_err(|v| {
                     self.make_type_mismatch_err::<FnPtr>(
                         self.map_type_name(v.type_name()),
                         first_arg_pos,
@@ -1080,6 +1089,8 @@ impl Engine {
                         let scope = &mut Scope::new();
                         let environ = environ.as_deref();
 
+                        defer! { let orig_level = global.level; global.level += 1 }
+
                         return self.call_script_fn(
                             global, caches, scope, None, environ, &fn_def, args, true, pos,
                         );
@@ -1128,7 +1139,7 @@ impl Engine {
                 let (first_arg_value, first_arg_pos) =
                     self.get_arg_value(global, caches, scope, this_ptr.as_deref_mut(), first)?;
 
-                let mut fn_ptr = first_arg_value.try_cast_raw::<FnPtr>().map_err(|v| {
+                let mut fn_ptr = first_arg_value.try_cast_result::<FnPtr>().map_err(|v| {
                     self.make_type_mismatch_err::<FnPtr>(
                         self.map_type_name(v.type_name()),
                         first_arg_pos,
