@@ -296,7 +296,7 @@ impl<'a> NativeCallContext<'a> {
 
         self._call_fn_raw(fn_name, args, false, false, false)
             .and_then(|result| {
-                result.try_cast_raw().map_err(|r| {
+                result.try_cast_result().map_err(|r| {
                     let result_type = self.engine().map_type_name(r.type_name());
                     let cast_type = match type_name::<T>() {
                         typ if typ.contains("::") => self.engine.map_type_name(typ),
@@ -329,7 +329,7 @@ impl<'a> NativeCallContext<'a> {
 
         self._call_fn_raw(fn_name, args, true, false, false)
             .and_then(|result| {
-                result.try_cast_raw().map_err(|r| {
+                result.try_cast_result().map_err(|r| {
                     let result_type = self.engine().map_type_name(r.type_name());
                     let cast_type = match type_name::<T>() {
                         typ if typ.contains("::") => self.engine.map_type_name(typ),
@@ -529,24 +529,35 @@ pub fn locked_read<T>(value: &Locked<T>) -> Option<LockGuard<T>> {
     return value.try_borrow().ok();
 
     #[cfg(feature = "sync")]
-    #[cfg(feature = "unchecked")]
-    return value.read().ok();
+    #[cfg(not(feature = "no_std"))]
+    {
+        #[cfg(feature = "unchecked")]
+        return value.read().ok();
+
+        #[cfg(not(feature = "unchecked"))]
+        {
+            // Spin-lock for a short while before giving up
+            for _ in 0..5 {
+                match value.try_read() {
+                    Ok(guard) => return Some(guard),
+                    Err(std::sync::TryLockError::WouldBlock) => {
+                        std::thread::sleep(std::time::Duration::from_millis(10))
+                    }
+                    Err(_) => return None,
+                }
+            }
+
+            return None;
+        }
+    }
 
     #[cfg(feature = "sync")]
-    #[cfg(not(feature = "unchecked"))]
+    #[cfg(feature = "no_std")]
     {
-        // Spin-lock for a short while before giving up
-        for _ in 0..10 {
-            match value.try_read() {
-                Ok(guard) => return Some(guard),
-                Err(std::sync::TryLockError::WouldBlock) => {
-                    std::thread::sleep(std::time::Duration::from_secs(1))
-                }
-                Err(_) => return None,
-            }
-        }
-
-        return None;
+        #[cfg(feature = "unchecked")]
+        return Some(value.read());
+        #[cfg(not(feature = "unchecked"))]
+        return value.try_read();
     }
 }
 
@@ -560,24 +571,35 @@ pub fn locked_write<T>(value: &Locked<T>) -> Option<LockGuardMut<T>> {
     return value.try_borrow_mut().ok();
 
     #[cfg(feature = "sync")]
-    #[cfg(feature = "unchecked")]
-    return value.write().ok();
+    #[cfg(not(feature = "no_std"))]
+    {
+        #[cfg(feature = "unchecked")]
+        return value.write().ok();
+
+        #[cfg(not(feature = "unchecked"))]
+        {
+            // Spin-lock for a short while before giving up
+            for _ in 0..5 {
+                match value.try_write() {
+                    Ok(guard) => return Some(guard),
+                    Err(std::sync::TryLockError::WouldBlock) => {
+                        std::thread::sleep(std::time::Duration::from_millis(10))
+                    }
+                    Err(_) => return None,
+                }
+            }
+
+            return None;
+        }
+    }
 
     #[cfg(feature = "sync")]
-    #[cfg(not(feature = "unchecked"))]
+    #[cfg(feature = "no_std")]
     {
-        // Spin-lock for a short while before giving up
-        for _ in 0..10 {
-            match value.try_write() {
-                Ok(guard) => return Some(guard),
-                Err(std::sync::TryLockError::WouldBlock) => {
-                    std::thread::sleep(std::time::Duration::from_secs(1))
-                }
-                Err(_) => return None,
-            }
-        }
-
-        return None;
+        #[cfg(feature = "unchecked")]
+        return Some(value.write());
+        #[cfg(not(feature = "unchecked"))]
+        return value.try_write();
     }
 }
 
